@@ -1,6 +1,5 @@
 import json
 import logging
-from datetime import datetime
 from io import BytesIO
 from pathlib import Path
 from typing import Any, BinaryIO, Callable, Dict, List, Literal, Optional, Type, Union
@@ -289,6 +288,7 @@ class AsyncFolder:
         use_colpali: bool = True,
         additional_folders: Optional[List[str]] = None,
         padding: int = 0,
+        output_format: Optional[str] = None,
     ) -> List[FinalChunkResult]:
         """
         Retrieve relevant chunks within this folder.
@@ -315,6 +315,7 @@ class AsyncFolder:
             folder_name=effective_folder,
             end_user_id=None,
             padding=padding,
+            output_format=output_format,
         )
 
     async def retrieve_docs(
@@ -491,6 +492,7 @@ class AsyncFolder:
         sources: List[Union[ChunkSource, Dict[str, Any]]],
         additional_folders: Optional[List[str]] = None,
         use_colpali: bool = True,
+        output_format: Optional[str] = None,
     ) -> List[FinalChunkResult]:
         """
         Retrieve specific chunks by their document ID and chunk number in a single batch operation within this folder.
@@ -499,12 +501,19 @@ class AsyncFolder:
             sources: List of ChunkSource objects or dictionaries with document_id and chunk_number
             additional_folders: Optional list of additional folder names to further scope operations
             use_colpali: Whether to use ColPali-style embedding model
+            output_format: Controls how image chunks are returned (e.g., "base64" or "url")
 
         Returns:
             List[FinalChunkResult]: List of chunk results
         """
         merged = self._merge_folders(additional_folders)
-        request = self._client._logic._prepare_batch_get_chunks_request(sources, merged, None, use_colpali)
+        request = self._client._logic._prepare_batch_get_chunks_request(
+            sources,
+            merged,
+            None,
+            use_colpali,
+            output_format,
+        )
         response = await self._client._request("POST", "batch/chunks", data=request)
         return self._client._logic._parse_chunk_result_list_response(response)
 
@@ -803,6 +812,7 @@ class AsyncUserScope:
         use_colpali: bool = True,
         additional_folders: Optional[List[str]] = None,
         padding: int = 0,
+        output_format: Optional[str] = None,
     ) -> List[FinalChunkResult]:
         """
         Retrieve relevant chunks as this end user.
@@ -815,6 +825,7 @@ class AsyncUserScope:
             use_colpali: Whether to use ColPali-style embedding model
             additional_folders: Optional list of additional folder names to further scope operations
             padding: Number of additional chunks/pages to retrieve before and after matched chunks (ColPali only, default: 0)
+            output_format: Controls how image chunks are returned (e.g., "base64" or "url")
 
         Returns:
             List[FinalChunkResult]: List of relevant chunks
@@ -829,6 +840,7 @@ class AsyncUserScope:
             folder_name=effective_folder,
             end_user_id=self._end_user_id,
             padding=padding,
+            output_format=output_format,
         )
 
     async def retrieve_docs(
@@ -1009,6 +1021,7 @@ class AsyncUserScope:
         sources: List[Union[ChunkSource, Dict[str, Any]]],
         folder_name: Optional[Union[str, List[str]]] = None,
         use_colpali: bool = True,
+        output_format: Optional[str] = None,
     ) -> List[FinalChunkResult]:
         """
         Retrieve specific chunks by their document ID and chunk number in a single batch operation for this end user.
@@ -1017,12 +1030,17 @@ class AsyncUserScope:
             sources: List of ChunkSource objects or dictionaries with document_id and chunk_number
             folder_name: Optional folder name (or list of names) to scope the request
             use_colpali: Whether to use ColPali-style embedding model
+            output_format: Controls how image chunks are returned (e.g., "base64" or "url")
 
         Returns:
             List[FinalChunkResult]: List of chunk results
         """
         request = self._client._logic._prepare_batch_get_chunks_request(
-            sources, self._folder_name, self._end_user_id, use_colpali
+            sources,
+            self._folder_name,
+            self._end_user_id,
+            use_colpali,
+            output_format,
         )
         response = await self._client._request("POST", "batch/chunks", data=request)
         return self._client._logic._parse_chunk_result_list_response(response)
@@ -1499,6 +1517,7 @@ class AsyncMorphik(_ScopedOperationsMixin):
         use_colpali: bool = True,
         folder_name: Optional[Union[str, List[str]]] = None,
         padding: int = 0,
+        output_format: Optional[str] = None,
     ) -> List[FinalChunkResult]:
         """
         Search for relevant chunks.
@@ -1525,6 +1544,7 @@ class AsyncMorphik(_ScopedOperationsMixin):
             folder_name=effective_folder,
             end_user_id=None,
             padding=padding,
+            output_format=output_format,
         )
 
     async def retrieve_docs(
@@ -2111,6 +2131,7 @@ class AsyncMorphik(_ScopedOperationsMixin):
         sources: List[Union[ChunkSource, Dict[str, Any]]],
         folder_name: Optional[Union[str, List[str]]] = None,
         use_colpali: bool = True,
+        output_format: Optional[str] = None,
     ) -> List[FinalChunkResult]:
         """
         Retrieve specific chunks by their document ID and chunk number in a single batch operation.
@@ -2119,12 +2140,19 @@ class AsyncMorphik(_ScopedOperationsMixin):
             sources: List of ChunkSource objects or dictionaries with document_id and chunk_number
             folder_name: Optional folder name (or list of names) to scope the request
             use_colpali: Whether to use ColPali-style embedding model
+            output_format: Controls how image chunks are returned (e.g., "base64" or "url")
 
         Returns:
             List[FinalChunkResult]: List of chunk results
 
         """
-        request = self._logic._prepare_batch_get_chunks_request(sources, folder_name, None, use_colpali)
+        request = self._logic._prepare_batch_get_chunks_request(
+            sources,
+            folder_name,
+            None,
+            use_colpali,
+            output_format,
+        )
         response = await self._request("POST", "batch/chunks", data=request)
         return self._logic._parse_chunk_result_list_response(response)
 
@@ -2383,31 +2411,6 @@ class AsyncMorphik(_ScopedOperationsMixin):
         limit_capped = max(1, min(limit, 500))
         return await self._request("GET", "chats", params={"limit": limit_capped})
 
-    # ------------------------------------------------------------------
-    # Usage API ---------------------------------------------------------
-    # ------------------------------------------------------------------
-    async def get_usage_stats(self) -> Dict[str, int]:
-        """Return cumulative token usage statistics (async)."""
-        return await self._request("GET", "usage/stats")
-
-    async def get_recent_usage(
-        self,
-        operation_type: Optional[str] = None,
-        since: Optional["datetime"] = None,
-        status: Optional[str] = None,
-    ) -> List[Dict[str, Any]]:
-        """Return recent usage entries with optional filtering (async)."""
-        from datetime import datetime
-
-        params: Dict[str, Any] = {}
-        if operation_type:
-            params["operation_type"] = operation_type
-        if since:
-            params["since"] = since.isoformat() if isinstance(since, datetime) else str(since)
-        if status:
-            params["status"] = status
-        return await self._request("GET", "usage/recent", params=params)
-
     # ------------------------------------------------------------------
     # Graph helpers -----------------------------------------------------
     # ------------------------------------------------------------------
