@@ -1,6 +1,5 @@
 import json
 import logging
-from datetime import datetime
 from io import BytesIO
 from pathlib import Path
 from typing import Any, BinaryIO, Callable, Dict, List, Literal, Optional, Type, Union
@@ -289,6 +288,7 @@ class Folder:
         use_colpali: bool = True,
         additional_folders: Optional[List[str]] = None,
         padding: int = 0,
+        output_format: Optional[str] = None,
     ) -> List[FinalChunkResult]:
         """
         Retrieve relevant chunks within this folder.
@@ -301,6 +301,7 @@ class Folder:
             use_colpali: Whether to use ColPali-style embedding model
             additional_folders: Optional list of extra folders to include in the scope
             padding: Number of additional chunks/pages to retrieve before and after matched chunks (ColPali only, default: 0)
+            output_format: Controls how image chunks are returned (e.g., "base64" or "url")
 
         Returns:
             List[FinalChunkResult]: List of relevant chunks
@@ -315,6 +316,7 @@ class Folder:
             folder_name=effective_folder,
             end_user_id=None,
             padding=padding,
+            output_format=output_format,
         )
 
     def retrieve_docs(
@@ -492,6 +494,7 @@ class Folder:
         sources: List[Union[ChunkSource, Dict[str, Any]]],
         additional_folders: Optional[List[str]] = None,
         use_colpali: bool = True,
+        output_format: Optional[str] = None,
     ) -> List[FinalChunkResult]:
         """
         Retrieve specific chunks by their document ID and chunk number in this folder.
@@ -500,12 +503,19 @@ class Folder:
             sources: List of ChunkSource objects or dictionaries with document_id and chunk_number
             additional_folders: Optional list of extra folders to include in the scope
             use_colpali: Whether to request multimodal chunks when available
+            output_format: Controls how image chunks are returned (e.g., "base64" or "url")
 
         Returns:
             List[FinalChunkResult]: List of chunk results
         """
         merged = self._merge_folders(additional_folders)
-        request = self._client._logic._prepare_batch_get_chunks_request(sources, merged, None, use_colpali)
+        request = self._client._logic._prepare_batch_get_chunks_request(
+            sources,
+            merged,
+            None,
+            use_colpali,
+            output_format,
+        )
 
         response = self._client._request("POST", "batch/chunks", data=request)
         return self._client._logic._parse_chunk_result_list_response(response)
@@ -823,6 +833,7 @@ class UserScope:
         use_colpali: bool = True,
         additional_folders: Optional[List[str]] = None,
         padding: int = 0,
+        output_format: Optional[str] = None,
     ) -> List[FinalChunkResult]:
         """
         Retrieve relevant chunks as this end user.
@@ -835,6 +846,7 @@ class UserScope:
             use_colpali: Whether to use ColPali-style embedding model
             additional_folders: Optional list of extra folders to include in the scope
             padding: Number of additional chunks/pages to retrieve before and after matched chunks (ColPali only, default: 0)
+            output_format: Controls how image chunks are returned (e.g., "base64" or "url")
 
         Returns:
             List[FinalChunkResult]: List of relevant chunks
@@ -849,6 +861,7 @@ class UserScope:
             folder_name=effective_folder,
             end_user_id=self._end_user_id,
             padding=padding,
+            output_format=output_format,
         )
 
     def retrieve_docs(
@@ -1029,6 +1042,7 @@ class UserScope:
         sources: List[Union[ChunkSource, Dict[str, Any]]],
         additional_folders: Optional[List[str]] = None,
         use_colpali: bool = True,
+        output_format: Optional[str] = None,
     ) -> List[FinalChunkResult]:
         """
         Retrieve specific chunks by their document ID and chunk number in this folder.
@@ -1037,12 +1051,19 @@ class UserScope:
             sources: List of ChunkSource objects or dictionaries with document_id and chunk_number
             additional_folders: Optional list of extra folders to include in the scope
             use_colpali: Whether to request multimodal chunks when available
+            output_format: Controls how image chunks are returned (e.g., "base64" or "url")
 
         Returns:
             List[FinalChunkResult]: List of chunk results
         """
         merged = self._merge_folders(additional_folders)
-        request = self._client._logic._prepare_batch_get_chunks_request(sources, merged, None, use_colpali)
+        request = self._client._logic._prepare_batch_get_chunks_request(
+            sources,
+            merged,
+            None,
+            use_colpali,
+            output_format,
+        )
 
         response = self._client._request("POST", "batch/chunks", data=request)
         return self._client._logic._parse_chunk_result_list_response(response)
@@ -1560,6 +1581,7 @@ class Morphik(_ScopedOperationsMixin):
         use_colpali: bool = True,
         folder_name: Optional[Union[str, List[str]]] = None,
         padding: int = 0,
+        output_format: Optional[str] = None,
     ) -> List[FinalChunkResult]:
         """
         Retrieve relevant chunks.
@@ -1585,6 +1607,7 @@ class Morphik(_ScopedOperationsMixin):
             folder_name=folder_name,
             end_user_id=None,
             padding=padding,
+            output_format=output_format,
         )
 
     def retrieve_docs(
@@ -2158,6 +2181,7 @@ class Morphik(_ScopedOperationsMixin):
         sources: List[Union[ChunkSource, Dict[str, Any]]],
         folder_name: Optional[Union[str, List[str]]] = None,
         use_colpali: bool = True,
+        output_format: Optional[str] = None,
     ) -> List[FinalChunkResult]:
         """
         Retrieve specific chunks by their document ID and chunk number.
@@ -2165,12 +2189,20 @@ class Morphik(_ScopedOperationsMixin):
         Args:
             sources: List of ChunkSource objects or dictionaries with document_id and chunk_number
             folder_name: Optional folder name (or list of names) to scope the request
+            use_colpali: Whether to request multimodal chunks when available
+            output_format: Controls how image chunks are returned (e.g., "base64" or "url")
 
         Returns:
             List[FinalChunkResult]: List of chunk results
 
         """
-        request = self._logic._prepare_batch_get_chunks_request(sources, folder_name, None, use_colpali)
+        request = self._logic._prepare_batch_get_chunks_request(
+            sources,
+            folder_name,
+            None,
+            use_colpali,
+            output_format,
+        )
         response = self._request("POST", "batch/chunks", data=request)
         return self._logic._parse_chunk_result_list_response(response)
 
@@ -2470,32 +2502,6 @@ class Morphik(_ScopedOperationsMixin):
         limit_capped = max(1, min(limit, 500))
         return self._request("GET", "chats", params={"limit": limit_capped})
 
-    # ------------------------------------------------------------------
-    # Usage API ---------------------------------------------------------
-    # ------------------------------------------------------------------
-    def get_usage_stats(self) -> Dict[str, int]:
-        """Return cumulative usage statistics for the authenticated user."""
-        return self._request("GET", "usage/stats")
-
-    def get_recent_usage(
-        self,
-        operation_type: Optional[str] = None,
-        since: Optional["datetime"] = None,
-        status: Optional[str] = None,
-    ) -> List[Dict[str, Any]]:
-        """Return recent usage records with optional filtering."""
-        from datetime import datetime  # Local import ensures small dependency surface
-
-        params: Dict[str, Any] = {}
-        if operation_type:
-            params["operation_type"] = operation_type
-        if since:
-            # Accept either ``str`` or ``datetime`` for *since*
-            params["since"] = since.isoformat() if isinstance(since, datetime) else str(since)
-        if status:
-            params["status"] = status
-        return self._request("GET", "usage/recent", params=params)
-
     # ------------------------------------------------------------------
     # Graph helpers -----------------------------------------------------
     # ------------------------------------------------------------------
